==> ejc-procurement-impl-3.0.0-20251215.045513-116-sources.jar: com/ejianc/business/procurement/perform/bean/PurchaseProjectAnswerEntity.java <==
package com.ejianc.business.procurement.perform.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 采购项目-应答文件评审清单
 * 
 * @author generator
 * 
 */
 @TableName("ejc_procurement_purchase_project_answer")
public class PurchaseProjectAnswerEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="score")
    private BigDecimal score; // 分值
    @TableField(value="type")
    private Integer type; // 类型
    @TableField(value="pid")
    private Long pid; // 主表主键
    @TableField(value="sequence")
    private Integer sequence; // 排序
    @TableField(value="name")
    private String name; // 评价项目
    @TableField(value="code")
    private String code; // 编码
    @TableField(value="parent_id")
    private Long parentId; // 父ID
    
    
    

    public BigDecimal getScore() {
        return score;
    }

    public void setScore(BigDecimal score) {
        this.score = score;
    }
    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }
    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }
    public Integer getSequence() {
        return sequence;
    }

    public void setSequence(Integer sequence) {
        this.sequence = sequence;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public Long getParentId() {
        return parentId;
    }

    public void setParentId(Long parentId) {
        this.parentId = parentId;
    }
    
}

==> ejc-procurement-impl-3.0.0-20251216.024558-129-sources.jar: com/ejianc/business/procurement/perform/bean/PurchaseProjectAnswerEntity.java <==
package com.ejianc.business.procurement.perform.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;

/**
 * 采购项目-应答文件评审清单
 * 
 * @author generator
 * 
 */
 @TableName("ejc_procurement_purchase_project_answer")
public class PurchaseProjectAnswerEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="score")
    private BigDecimal score; // 分值
    @TableField(value="type")
    private Integer type; // 类型
    @TableField(value="pid")
    private Long pid; // 主表主键
    @TableField(value="sequence")
    private Integer sequence; // 排序
    @TableField(value="name")
    private String name; // 评价项目
    @TableField(value="code")
    private String code; // 编码
    @TableField(value="parent_id")
    private Long parentId; // 父ID
    @TableField(value="source_id")
    private Long sourceId; // sourceId

    @TableField(exist = false)
    private String tid;
    @TableField(exist = false)
    private String tpid;

    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }

    public String getTid() {
        return tid;
    }

    public void setTid(String tid) {
        this.tid = tid;
    }

    public String getTpid() {
        return tpid;
    }

    public void setTpid(String tpid) {
        this.tpid = tpid;
    }

    public BigDecimal getScore() {
        return score;
    }

    public void setScore(BigDecimal score) {
        this.score = score;
    }
    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }
    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }
    public Integer getSequence() {
        return sequence;
    }

    public void setSequence(Integer sequence) {
        this.sequence = sequence;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public Long getParentId() {
        return parentId;
    }

    public void setParentId(Long parentId) {
        this.parentId = parentId;
    }
    
}
